@@ -18,5 +18,13 @@ class AliasConfig(BaseYamlConfigModel):
 
     _not_none = validator("*", pre=True, allow_reuse=True)(default_if_none)
 
-    def resolve(self, alias):
+    def is_alias(self, alias: str):
+        return alias in self.aliases
+
+    def resolve(self, alias: str):
         return self.aliases.get(alias, alias)
+
+    def path_to_alias(self, path: Path):
+        path = path.resolve()
+        ret = [k for k, p in self.aliases.items() if p.resolve() == path][0]
+        return path if not ret else ret
