@@ -172,13 +172,14 @@ class Config(BaseYamlConfigModelWithBase):
         ),
     )
     devcontainer: Optional[DevcontainerConfig] = DevcontainerConfig()
-    vscode: Optional[VSCodeConfig] = VSCodeConfig()
+    # vscode: Optional[VSCodeConfig] = VSCodeConfig()
     docker: Optional[DockerConfig] = DockerConfig()
 
     _not_none = validator("*", pre=True, allow_reuse=True)(default_if_none)
 
     def resolve(self) -> "ResolvedConfig":
-        values = self.dict() | GlobalVariables().dict()
+        values = self.dict()
+        values.update(GlobalVariables().dict())
 
         cfg_copy: Config = self.copy(deep=True)
         cfg_copy.devcontainer.workspace_mount = (
